espejito.instrument


instrument-measureclj

(instrument-measure var-or-varname)
(instrument-measure
  var-or-varname
  {:keys [name-encoder] :or {name-encoder shorten-ns} :as options})

Given a fully qualified var name, instrument the var such that upon execution it participates in Espejito latency measurement.

Given a fully qualified var name, instrument the var such that upon execution it participates in Espejito latency measurement.
sourceraw docstring

resolve-varclj

(resolve-var fq-var-name)

Given a fully qualified var name, resolve the var object and return it.

Given a fully qualified var name, resolve the var object and return it.
sourceraw docstring

shorten-nsclj

(shorten-ns fq-var-name)
(shorten-ns fq-var-name {:keys [intact-token-count] :or {intact-token-count 2}})

Given a fully qualified var name, shorten the namespace portion for conciseness and readability and return the fully qualified short name.

Given a fully qualified var name, shorten the namespace portion for
conciseness and readability and return the fully qualified short name.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries