(collect-child-report transient-collector
level
[name cumulative-latency-ns thrown? children-metrics])(collect-children-report transient-collector level children-metrics)(expected expectation found)(expected pred expectation found)Throw illegal input exception citing expectation and what was found did not match. Optionally accept a predicate
fn to test found before throwing the exception.
Throw illegal input exception citing `expectation` and what was `found` did not match. Optionally accept a predicate fn to test `found` before throwing the exception.
(human-readable-latency nanos)Convert nano-second latency to human-readable form
Convert nano-second latency to human-readable form
(nanos)(nanos start)Return duration in nanoseconds since Epoch, or since the supplied timestamp (in nanos).
Return duration in nanoseconds since Epoch, or since the supplied timestamp (in nanos).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |